package cn.com.infosec.ocsp;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.ocsp.BasicOCSPResponse;
import cn.com.infosec.asn1.ocsp.CertID;
import cn.com.infosec.asn1.ocsp.CertStatus;
import cn.com.infosec.asn1.ocsp.ResponderID;
import cn.com.infosec.asn1.ocsp.ResponseData;
import cn.com.infosec.asn1.ocsp.RevokedInfo;
import cn.com.infosec.asn1.ocsp.SingleResponse;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.CRLReason;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Extensions;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.Signature;
import java.security.cert.CertificateEncodingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

public class BasicOCSPRespGenerator {
   private List list;
   private X509Extensions responseExtensions;
   private RespID responderID;

   private DERObject makeObj(byte[] encoding) {
      return encoding == null ? null : (new ASN1InputStream(encoding)).readObject();
   }

   public BasicOCSPRespGenerator(RespID responderID) {
      BasicOCSPRespGenerator var10000 = this;
      BasicOCSPRespGenerator var10001 = this;
      BasicOCSPRespGenerator var10002 = this;
      super();
      ArrayList var2;
      var2 = new ArrayList.<init>();
      var10002.list = var2;
      var10001.responseExtensions = null;
      var10000.responderID = responderID;
   }

   public BasicOCSPRespGenerator(PublicKey key) {
      BasicOCSPRespGenerator var10000 = this;
      BasicOCSPRespGenerator var10001 = this;
      BasicOCSPRespGenerator var10002 = this;
      super();
      ArrayList var2;
      var2 = new ArrayList.<init>();
      var10002.list = var2;
      var10001.responseExtensions = null;
      RespID var3;
      var3 = new RespID.<init>(key);
      var10000.responderID = var3;
   }

   private BasicOCSPResp generateResponse(String signatureName, PrivateKey key, X509Certificate[] chain, Date producedAt, String provider, SecureRandom random) {
      String var10000 = signatureName;
      Iterator var7 = this.list.iterator();

      DERObjectIdentifier var44;
      try {
         var44 = OCSPUtil.getAlgorithmOID(var10000);
      } catch (Exception var11) {
         throw new IllegalArgumentException("unknown signing algorithm specified");
      }

      DERObjectIdentifier var8 = var44;
      ASN1EncodableVector var9;
      var9 = new ASN1EncodableVector.<init>();

      while(var7.hasNext()) {
         try {
            var9.add(((ResponseObject)var7.next()).toResponse());
         } catch (Exception var10) {
            throw new OCSPException("exception creating Request", var10);
         }
      }

      String var10001 = signatureName;
      String var10002 = provider;
      ResponseData signatureName1;
      ResponseData var10003 = signatureName1 = new ResponseData;
      ResponderID provider1 = this.responderID.toASN1Object();
      DERGeneralizedTime var42;
      var42 = new DERGeneralizedTime.<init>(producedAt);
      DERSequence producedAt1;
      producedAt1 = new DERSequence.<init>(var9);
      X509Extensions var43 = this.responseExtensions;
      var10003.<init>(provider1, var42, producedAt1, var43);

      Signature producedAt2;
      boolean var47;
      label117: {
         NoSuchAlgorithmException var46;
         label116: {
            InvalidKeyException var45;
            label115: {
               Signature var48;
               try {
                  var48 = Signature.getInstance(var10001, var10002);
               } catch (NoSuchAlgorithmException var24) {
                  var46 = var24;
                  var47 = false;
                  break label116;
               } catch (InvalidKeyException var25) {
                  var45 = var25;
                  var47 = false;
                  break label115;
               }

               producedAt2 = var48;
               if (random != null) {
                  try {
                     producedAt2.initSign(key, random);
                     break label117;
                  } catch (NoSuchAlgorithmException var20) {
                     var46 = var20;
                     var47 = false;
                     break label116;
                  } catch (InvalidKeyException var21) {
                     var45 = var21;
                     var47 = false;
                  }
               } else {
                  try {
                     producedAt2.initSign(key);
                     break label117;
                  } catch (NoSuchAlgorithmException var22) {
                     var46 = var22;
                     var47 = false;
                     break label116;
                  } catch (InvalidKeyException var23) {
                     var45 = var23;
                     var47 = false;
                  }
               }
            }

            InvalidKeyException var26 = var45;
            throw new OCSPException("exception creating signature: " + var26, var26);
         }

         NoSuchAlgorithmException var27 = var46;
         throw new OCSPException("exception creating signature: " + var27, var27);
      }

      DERBitString key2;
      X509Certificate[] var54;
      DERObjectIdentifier var55;
      label104: {
         Exception var53;
         label127: {
            Signature var49;
            ByteArrayOutputStream var52;
            try {
               var54 = chain;
               var55 = var8;
               var49 = producedAt2;
               var52 = new ByteArrayOutputStream;
            } catch (Exception var19) {
               var53 = var19;
               var47 = false;
               break label127;
            }

            ByteArrayOutputStream key1;
            ByteArrayOutputStream var10004 = key1 = var52;

            DEROutputStream var56;
            try {
               var10004.<init>();
               var56 = new DEROutputStream;
            } catch (Exception var18) {
               var53 = var18;
               var47 = false;
               break label127;
            }

            DEROutputStream var10005 = var56;

            DERBitString var50;
            try {
               var10005.<init>(key1);
               var56.writeObject(signatureName1);
               var49.update(var52.toByteArray());
               var50 = new DERBitString;
            } catch (Exception var17) {
               var53 = var17;
               var47 = false;
               break label127;
            }

            key2 = var50;

            try {
               var50.<init>(producedAt2.sign());
               break label104;
            } catch (Exception var16) {
               var53 = var16;
               var47 = false;
            }
         }

         Exception var28 = var53;
         throw new OCSPException("exception processing TBSRequest: " + var28, var28);
      }

      AlgorithmIdentifier producedAt3 = OCSPUtil.getSigAlgID(var55);
      BasicOCSPResponse var30;
      if (var54 != null && chain.length > 0) {
         ASN1EncodableVector provider2;
         provider2 = new ASN1EncodableVector.<init>();
         int random1 = 0;

         while(true) {
            label81: {
               IOException var58;
               label80: {
                  CertificateEncodingException var57;
                  label129: {
                     int var59;
                     int var60;
                     try {
                        var59 = random1;
                        var60 = chain.length;
                     } catch (IOException var14) {
                        var58 = var14;
                        var47 = false;
                        break label80;
                     } catch (CertificateEncodingException var15) {
                        var57 = var15;
                        var47 = false;
                        break label129;
                     }

                     if (var59 == var60) {
                        BasicOCSPResponse var51 = var30 = new BasicOCSPResponse;
                        DERSequence chain1;
                        chain1 = new DERSequence.<init>(provider2);
                        var51.<init>(signatureName1, producedAt3, key2, chain1);
                        return new BasicOCSPResp(var30);
                     }

                     try {
                        provider2.add(new X509CertificateStructure((ASN1Sequence)this.makeObj(chain[random1].getEncoded())));
                        break label81;
                     } catch (IOException var12) {
                        var58 = var12;
                        var47 = false;
                        break label80;
                     } catch (CertificateEncodingException var13) {
                        var57 = var13;
                        var47 = false;
                     }
                  }

                  CertificateEncodingException var31 = var57;
                  throw new OCSPException("error encoding certs", var31);
               }

               IOException var32 = var58;
               throw new OCSPException("error processing certs", var32);
            }

            ++random1;
         }
      } else {
         var30 = new BasicOCSPResponse.<init>(signatureName1, producedAt3, key2, (ASN1Sequence)null);
         return new BasicOCSPResp(var30);
      }
   }

   public void addResponse(CertificateID certID, CertificateStatus certStatus) {
      List var10000 = this.list;
      BasicOCSPRespGenerator var10003 = this;
      Date var3;
      var3 = new Date.<init>();
      var10000.add(var10003.new ResponseObject(certID, certStatus, var3, (Date)null, (X509Extensions)null));
   }

   public void addResponse(CertificateID certID, CertificateStatus certStatus, X509Extensions singleExtensions) {
      List var10000 = this.list;
      BasicOCSPRespGenerator var10003 = this;
      Date var4;
      var4 = new Date.<init>();
      var10000.add(var10003.new ResponseObject(certID, certStatus, var4, (Date)null, singleExtensions));
   }

   public void addResponse(CertificateID certID, CertificateStatus certStatus, Date nextUpdate, X509Extensions singleExtensions) {
      List var10000 = this.list;
      BasicOCSPRespGenerator var10003 = this;
      Date var5;
      var5 = new Date.<init>();
      var10000.add(var10003.new ResponseObject(certID, certStatus, var5, nextUpdate, singleExtensions));
   }

   public void addResponse(CertificateID certID, CertificateStatus certStatus, Date thisUpdate, Date nextUpdate, X509Extensions singleExtensions) {
      this.list.add(new ResponseObject(certID, certStatus, thisUpdate, nextUpdate, singleExtensions));
   }

   public void setResponseExtensions(X509Extensions responseExtensions) {
      this.responseExtensions = responseExtensions;
   }

   public BasicOCSPResp generate(String signingAlgorithm, PrivateKey key, X509Certificate[] chain, Date thisUpdate, String provider) {
      return this.generate(signingAlgorithm, key, chain, thisUpdate, provider, (SecureRandom)null);
   }

   public BasicOCSPResp generate(String signingAlgorithm, PrivateKey key, X509Certificate[] chain, Date producedAt, String provider, SecureRandom random) {
      if (signingAlgorithm != null) {
         return this.generateResponse(signingAlgorithm, key, chain, producedAt, provider, random);
      } else {
         throw new IllegalArgumentException("no signing algorithm specified");
      }
   }

   public Iterator getSignatureAlgNames() {
      return OCSPUtil.getAlgNames();
   }

   private class ResponseObject {
      CertificateID certId;
      CertStatus certStatus;
      DERGeneralizedTime thisUpdate;
      DERGeneralizedTime nextUpdate;
      X509Extensions extensions;

      public ResponseObject(CertificateID certId, CertificateStatus certStatus, Date thisUpdate, Date nextUpdate, X509Extensions extensions) {
         this.certId = certId;
         CertStatus var7;
         if (certStatus == null) {
            var7 = new CertStatus.<init>();
            this.certStatus = var7;
         } else if (certStatus instanceof UnknownStatus) {
            CertStatus var10001 = var7 = new CertStatus;
            DERNull certId1;
            certId1 = new DERNull.<init>();
            var10001.<init>(2, certId1);
            this.certStatus = var7;
         } else {
            RevokedStatus var8;
            if ((var8 = (RevokedStatus)certStatus).hasRevocationReason()) {
               DERGeneralizedTime var10005 = new DERGeneralizedTime(var8.getRevocationTime());
               CRLReason certId2;
               certId2 = new CRLReason.<init>(var8.getRevocationReason());
               this.certStatus = new CertStatus(new RevokedInfo(var10005, certId2));
            } else {
               this.certStatus = new CertStatus(new RevokedInfo(new DERGeneralizedTime(var8.getRevocationTime()), (CRLReason)null));
            }
         }

         DERGeneralizedTime var9;
         var9 = new DERGeneralizedTime.<init>(thisUpdate);
         this.thisUpdate = var9;
         if (nextUpdate != null) {
            var9 = new DERGeneralizedTime.<init>(nextUpdate);
            this.nextUpdate = var9;
         } else {
            this.nextUpdate = null;
         }

         this.extensions = extensions;
      }

      public SingleResponse toResponse() {
         ResponseObject var10002 = this;
         ResponseObject var10003 = this;
         ResponseObject var10004 = this;
         ResponseObject var10005 = this;
         CertID var5 = this.certId.toASN1Object();
         CertStatus var1 = var10005.certStatus;
         DERGeneralizedTime var2 = var10004.thisUpdate;
         DERGeneralizedTime var3 = var10003.nextUpdate;
         X509Extensions var4 = var10002.extensions;
         return new SingleResponse(var5, var1, var2, var3, var4);
      }
   }
}
